@@ -494,7 +494,6 @@ class VoVNet(tf.keras.Model):
         **kwargs
     ):
         super(VoVNet, self).__init__(**kwargs)
-        self.resize = Resizing(height=224, width=224)
         self.in_size = in_size
         self.classes = classes
         self.data_format = data_format
@@ -539,7 +538,6 @@ class VoVNet(tf.keras.Model):
         self.flatten = Flatten(data_format=self.data_format)
 
     def call(self, x, training=None):
-        x = self.resize(x)
         x = self.features(x, training=training)
         x = self.flatten(x)
         x = self.output1(x)
@@ -597,7 +595,7 @@ def get_vovnet(
 
 
 def VoVNet27(classes=1000):
-    input_layer = Input(shape=(128, 128, 3,))
+    input_layer = Input(shape=(224, 224, 3,))
     x = get_vovnet(
         blocks=27, model_name="vovnet27", classes=classes, data_format="channels_last"
     )(input_layer)
@@ -606,7 +604,7 @@ def VoVNet27(classes=1000):
 
 
 def VoVNet39(classes=1000):
-    input_layer = Input(shape=(128, 128, 3,))
+    input_layer = Input(shape=(224, 224, 3,))
     x = get_vovnet(
         blocks=39, model_name="vovnet39", classes=classes, data_format="channels_last"
     )(input_layer)
@@ -615,9 +613,9 @@ def VoVNet39(classes=1000):
 
 
 def VoVNet57(classes=1000):
-    input_layer = Input(shape=(128, 128, 3,))
+    input_layer = Input(shape=(224, 224, 3,))
     x = get_vovnet(
         blocks=57, model_name="vovnet57", classes=classes, data_format="channels_last"
     )(input_layer)
     model = Model(inputs=input_layer, outputs=x)
-    return model
+    return model
\ No newline at end of file
